function [s, HS_L, HS_R, warn_max, warn_min] = calc_SW(RHEE_filt,LHEE_filt,sample_length,visual_check)
warn_max = 0;
warn_min = 0;

%% Determine HS
%determine left heel strike
LHEE_min = islocalmin(LHEE_filt(:,3),'MinSeparation',60);         %find local minimum of Z marker
LHEE_min_check = LHEE_filt(:,3) < (min(LHEE_filt(:,3)) + 20);     %find where marker within 20 mm of the bottom
HS_L = logical(LHEE_min .* LHEE_min_check);                       %create logical where both are true

%removing first and last logical 1's to remove local minima near edges of 
indices = find(HS_L);
HS_L(indices(1)) = 0;
HS_L(indices(end)) = 0;

%determine right heel strike
RHEE_min = islocalmin(RHEE_filt(:,3),'MinSeparation',60);         %find local minimum of Z marker
RHEE_min_check = RHEE_filt(:,3) < (min(RHEE_filt(:,3)) + 20);     %find where marker is below 20 mm
HS_R = logical(RHEE_min .* RHEE_min_check);                       %create logical where both are true

%removing first and last logical 1's to remove local minima near edges of 
indices = find(HS_R);
HS_R(indices(1)) = 0;
HS_R(indices(end)) = 0;


%all HS
HS_all = or(HS_L,HS_R); %combine logicals left and right heelstrike


%determine step width at heel strike
RL_dist = -(RHEE_filt(:,2)-LHEE_filt(:,2));  %calc SW across entire measurement

SW_all = RL_dist(HS_all);                    %SW at all HS
SW_L = RL_dist(HS_L);                        %SW at left HS
SW_R = RL_dist(HS_R);                        %SW at right HS

% warning if SW out of logical bounds
if max(SW_all)>250
    warn_max = 1;
end 

if min(SW_all)<-60
    warn_min = 1;
end 

%calculate means, vars, and make struct
s.SW_all = SW_all;              
s.SW_all_mean = mean(SW_all);    %mean SW all HS
s.SW_all_var = var(SW_all);      %var SW at all HS
s.SW_all_SD = std(SW_all);          % SD SW at all HS
s.SW_all_CV = (s.SW_all_SD / s.SW_all_mean) * 100; % CV WS at all HS
s.SW_all_max = max(SW_all);     %max SW all HS
s.SW_all_min = min(SW_all);     %min SW all HS

s.SW_L = SW_L;
s.SW_L_mean = mean(SW_L);        %mean SW at left HS
s.SW_L_var = var(SW_L);          %var SW at left HS    
s.SW_L_SD = std(SW_L);          % SD SW at L HS
s.SW_L_CV = (s.SW_L_SD / s.SW_L_mean) * 100; % CV WS at L HS

s.SW_R = SW_R;
s.SW_R_mean = mean(SW_R);        %mean SW at right HS
s.SW_R_var = var(SW_R);          %var SW at right HS
s.SW_R_SD = std(SW_R);          % SD SW at R HS
s.SW_R_CV = (s.SW_R_SD / s.SW_R_mean) * 100; % CV WS at R HS

%% Plot HS detection for visual inspection

if visual_check == 1
    x = 1:sample_length;
    
    subplot(2,2,1)
    plot(x,LHEE_filt(:,3),x(HS_L),LHEE_filt(HS_L,3),'r*')
    ylabel('height (mm)')
    xlabel('time (ms)')
    title('LHEE_filt','Interpreter','none')
    
%     subplot(2,2,2)
%     plot(x,RHEE_filt(:,3),x(HS_R),RHEE_filt(HS_R,3),'r*')
%     ylabel('height (mm)')
%     xlabel('time (ms)')
%     title('RHEE_filt','Interpreter','none')

    subplot(2,2,3)
    plot(SW_all)
    ylabel('step width (mm)')
    xlabel('step nr.')
    title('SW_all','Interpreter','none')

end

