function [gOMEGAseg_norm, eX_trunk, eY_trunk, eZ_trunk, NECK_filt] = calc_trunkOmega(NECK_filt,PELV_filt,RSHO_filt,HS_L,Fs,vc_trunk)
%this function calculates the stride normalized trunk angular velocity
%based on head and neck markers
% 
% for idx = 1:length(LASI_filt) 
%     %calc center point of pelvis and neck (upper trunk)
%     if (isnan(RASI_filt(idx)) || isnan(LPSI_filt(idx))) && (isnan(LASI_filt(idx)) || isnan(RPSI_filt(idx)))
%         PELV_filt(idx,1:3) = NaN;
%     elseif isnan(RASI_filt(idx)) || isnan(LPSI_filt(idx))
%         PELV_filt(idx,:) = (LASI_filt(idx,:) + RPSI_filt(idx,:))./2;
%     elseif isnan(LASI_filt(idx)) || isnan(RPSI_filt(idx))
%         PELV_filt(idx,:) = (RASI_filt(idx,:) + LPSI_filt(idx,:))./2;
%     else 
%         PELV_filt(idx,:) = (LASI_filt(idx,:) + RASI_filt(idx,:) + LPSI_filt(idx,:) + RPSI_filt(idx,:))./4;
%     end
% 
%     if (isnan(STRN_filt(idx)) || isnan(C7_filt(idx))) && (isnan(STRN_filt(idx)) || isnan(C7_filt(idx)))
%          NECK_filt(idx,1:3) = NaN;
%     elseif isnan(STRN_filt(idx)) || isnan(C7_filt(idx))
%         NECK_filt(idx,:) = (LSHO_filt(idx,:) + RSHO_filt(idx,:))./2;
%     elseif isnan(STRN_filt(idx)) || isnan(C7_filt(idx))
%         NECK_filt(idx,:) = (LSHO_filt(idx,:) + RSHO_filt(idx,:))./2;
%     else
%         NECK_filt(idx,:) = (LSHO_filt(idx,:) + STRN_filt(idx,:) + C7_filt(idx,:) + RSHO_filt(idx,:))./4;
%     end
% end 

%creating unit vectors for trunk triad on all samples
[eX_trunk, eY_trunk, eZ_trunk] = triad(NECK_filt,RSHO_filt,PELV_filt);

for idx = 1:length(eZ_trunk)

    %creating R for trunk segment for angular_vel_3d function
    gRseg(idx,:) = [eX_trunk(idx,:) eY_trunk(idx,:) eZ_trunk(idx,:)];   %rad
end

%calculating Omega from rotation matrix of trunk segment
[gOMEGAseg, segOMEGAseg] = angular_vel_3d(gRseg,Fs);        %rad/s

%calc combined angular velocity on x and y axis, yaw is disregarded
gOMEGAseg_sum = sum(gOMEGAseg,2);                           %rad/s
segOMEGAseg_sum = sum(segOMEGAseg,2);                       %rad/s

%% normalizing to stride cycle

%find all HS_L frames
HS_L_frames = find(HS_L == 1);

for idx = 1:length(HS_L_frames)-1
    %create snippet of gOMEGA from HS to HS
    gOMEGAseg_snip = gOMEGAseg(HS_L_frames(idx):HS_L_frames(idx+1),2);
    
    %calc resampling rate
    snip_ratio = 100/length(gOMEGAseg_snip);

    %resample snippet to have 100 samples (1 per % of gaitcycle)
    %and convert to deg/s
    gOMEGAseg_norm.data(idx,:) = rad2deg(scale_sample_rate_linear(gOMEGAseg_snip,snip_ratio)); %deg/s
    gOMEGAseg_norm.mean = mean(gOMEGAseg_norm.data,1,'omitnan');
    gOMEGAseg_norm.max = max(gOMEGAseg_norm.data,[],1);
    gOMEGAseg_norm.min = min(gOMEGAseg_norm.data,[],1);
    gOMEGAseg_norm.std = std(gOMEGAseg_norm.data,[],1,"omitnan");
    gOMEGAseg_norm.stdmean = mean(gOMEGAseg_norm.std);
    %plot each stride cycle
    %plot(gOMEGAseg_norm.data(idx,:))

end

%% visual inspection of max-min and mean lines

if vc_trunk
    x = 1:100;
    x2 = [x fliplr(x)];
    inBetween = [gOMEGAseg_norm.max fliplr(gOMEGAseg_norm.min)];

    subplot(2,2,2)
    fill(x2,inBetween,[0.9804 0.8431 0.7843],'LineStyle','none')            %area from max to min
    
    hold on
    plot(gOMEGAseg_norm.mean,'Color',[0.8500 0.3250 0.0980],'LineWidth',2)  %plot mean line
    hold off

    %plot(gOMEGAseg_norm.data')                                             %overlay all measurements
    ylabel('angular velocity (deg/s)')
    xlabel('gait cycle (%)')
    
    subplot(2,2,4)
    plot(gOMEGAseg_norm.std,'b:')
    ylabel('Seg Omega (SD)')
    xlabel('gait cycle (%)')
end

