function [smooth]=filtcol_new(data,Fs,Fc,ord,fb,high_low_stop,correct_Fc)
%
% [smooth]=filtcol_new(data,Fs,Fc,ord,fb,high_low_stop,correct_Fc)
%
% % input
% Fs  :sample frequentie
% Fc  :cut-off frequency (If Fc contains 2 values a bandpass filter is applied)
% % optional input 
% ord               : is optional the order (devault is 2nd order)
% fb = 'fb' or []   : filter forward and backward (default is forward-backward);
% fb = 'f'          : filter only forward
% fb = 'b'          : filter only backward
% high_low_stop     : kind of filter ('high', 'low' or 'stop') (devault 'low' if one Fc is given and 'band pass' when 2 Fc's are given)
% correct_Fc        : if correct_Fc== 1 : correction of Fc (Fc/0.802, Winter, Biomechanics of moter control, p48)
%                     in case of a 2nd order high or low pass forward-backward-filtering below 50 Hz
%                     Should and will not be applied in other cases (see test functions in
%                     3dmodel up2date) (devault off)
%             %                     
% %output
% smooth: filtered signal

[m,n]=size(data);
if n>m;  error ('this function filters collums, number of rows must be > number of collums');end
if nargin < 4;      ord = 2                 ;end
if isempty(ord);    ord = 2                 ;end
if nargin < 5;      fb = 'fb'               ;end
if isempty(fb);     fb = 'fb'               ;end
if nargin < 6;      high_low_stop = []      ;end
if nargin < 7;      correct_Fc = 0          ;end

if correct_Fc==1 && strcmp(fb,'fb') && max(Fc)<=50 && max(size(Fc))==1 && ord==2
    Fc=Fc/0.802;
elseif correct_Fc==1
    disp('Warning: requested correction of Fc is not applied because of the following reasons')
    if ~strcmp(fb,'fb');   disp('filter is not forward-backward filter'); end
    if max(Fc)>50;        disp('Fc > 50');end
    if max(size(Fc))~=1;  disp('Fc has more than 1 element (is no high or low pass filter)');end
    if ord~=2;             disp('ord ~= 2');end
end

if isempty(high_low_stop);
  [B,A]=butter(ord,Fc./(Fs/2));     
else
  [B,A]=butter(ord,Fc./(Fs/2),high_low_stop);     
end;

if fb == 'f';
    smooth = filter(B,A,data);
elseif fb == 'b';
    smooth = flipud(filter(B,A,flipud(data)));
elseif fb == 'fb'
    smooth = filtfilt(B,A,data);
end