% Single runs
% Bram

filename = ['NAN_check'];

%only run if filename exists, otherwise return
fid = fopen('.path_data.txt','r');
path = fscanf(fid,'%s');

if isfile([path '\' filename '.mat'])
    
    data = load_data(filename);     %loading data
    condition_name = char(conditions(condition_id));
    fclose(fid);
    
    %% Organize marker data
    mdata = data.(filename).Trajectories.Labeled.Data;                 %assign data
    mlabels = data.(filename).Trajectories.Labeled.Labels;             %assign labels
    mframes = data.(filename).Frames;                                  %length of measurement
    etimes = cell2mat({data.(filename).Events.Time});                  %assign event times
    elabels = convertCharsToStrings({data.(filename).Events.Label});   %assign event labels
    eframes = round(cell2mat({data.(filename).Events.Frame}),0);       %assign event frames
    
    %if no markers are present in qtm data an empty event is made to prevent errors in plotting
    if isempty(eframes)
        etimes = zeros(1);
        elabels = zeros(1);
        eframes = zeros(1);
    end
    
    %% Assign data to variabels and cut sample to length
    
    for idx = 9
        %filling temporary array and squeezing
        temp = mdata(idx,1:3,:);
        temp = squeeze(temp)';
        
        %spline interpolate data and select sample
        [temp_int,ones_gaps_limit_all,ones_gaps_all] = spline_interp_find_gaps(temp,0);     %interpolates (spline) all the gaps in the data (for each column)
        
        if not(isnan(temp_int(20)))
            [temp_filt] = filtcol_new(temp_int,Fs,Fc);                                      %filter columns
            
            %populating markerlabels
            eval([char(mlabels(idx)) '_filt = temp_filt;']);
        end
    end
    
    %specify required labels for use in further functions
    required_labels = {'LASI_filt' 'RASI_filt' 'LPSI_filt' 'RPSI_filt' 'LSHO_filt' 'STRN_filt' 'C7_filt' 'RSHO_filt'};
    
    %create empty variables if labels don't exist
    for idx = 1:length(required_labels)
        if ~exist(char(required_labels(idx)))
            eval([char(required_labels(idx)) ' = [];']);
        end
    end
    
    %visual inspection
%     %subplot(2,2,1)
%         if vc_RHEE
%         subplot(2,1,1)
%         plot(RHEE_filt(:,3))
%         xline(eframes,'r')
%         subplot(2,1,2)
%         plot(LHEE_filt(:,3))
%         xline(eframes,'r')
%         
%         pause(1)
%     end

    
    %calculate time between ML markers
    try
        ML_time = etimes(2)-etimes(1);
        if ML_time > 30
            ML_time = 30;
        end
    catch
        ML_time = 'NAN'
    end
    
    %calculate distance between last step and first step
    try
        if elabels(2) == "br"
            R_distance = norm(RHEE_filt(eframes(2)) - RHEE_filt(eframes(1)));
            L_distance = norm(RHEE_filt(eframes(2)) - LHEE_filt(eframes(1)));
            beam_dist = min(5,min(R_distance,L_distance)/1000); %convert to meter and limit to 5m
        elseif elabels(2) == "bl"
            R_distance = norm(LHEE_filt(eframes(2)) - RHEE_filt(eframes(1)));
            L_distance = norm(LHEE_filt(eframes(2)) - LHEE_filt(eframes(1)));
            beam_dist = min(5,min(R_distance,L_distance)/1000); %conver to meter and limti to 5m
        end
    catch
        beam_dist = 'NAN'
    end
    
    %calculate time from AP marker to end
    try
        AP_time = (mframes - eframes(1))/100;
        if AP_time > 30
            AP_time = 30;
        end
    catch
        AP_time = 'NAN'
    end
    
    %% creating trial array for exporting to R
    trial_headers = {'ID' 'condition' 'trial_nr' 'ML_time' 'beam_dist' 'AP_time'}; %'omega_stdmean'
    trial_array = {p_id char(conditions(condition_id)) trial_id ML_time beam_dist AP_time}; %trial_trunk(trial_id).stdmean
    
%     if ~exist('output_mat')
%         output_mat = trial_array;
%     else
%         output_mat = vertcat(output_mat, trial_array);
%     end
    
    %p(p_id).(char(conditions(condition_id))).sw = trial_sw;   %assign SW trial struct to main structure
    %p(p_id).(char(conditions(condition_id))).sw_all_mean = mean([p(p_id).(char(conditions(condition_id))).sw.SW_all_mean]);
    
    %p(p_id).(char(conditions(condition_id))).omega = trial_trunk;   %assign trunk trial struct to main structure
    %p(p_id).(char(conditions(condition_id))).omega_std_all = mean([p(p_id).(char(conditions(condition_id))).omega.stdmean]);
end
